Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9911)

Unified Diff: chrome/common/render_messages_internal.h

Issue 4924001: JavaScript to Value bridge. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Go back to using seconds, use UTC for reliability in the test. Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/render_messages_internal.h
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 34b5bf083f79bcdc3ffdbcebe79a847cea7e5b55..1ff22d47da22f4f7625de0703f1433bb6e1d18e3 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -45,6 +45,7 @@
// Substitution map for l10n messages.
typedef std::map<std::string, std::string> SubstitutionMap;
+class Value;
class GPUInfo;
class SerializedScriptValue;
class SkBitmap;
@@ -3028,11 +3029,12 @@ IPC_BEGIN_MESSAGES(ViewHost)
SkBitmap /* thumbnail */)
// Response from ViewMsg_ScriptEvalRequest. The ID is the parameter supplied
// to ViewMsg_ScriptEvalRequest. The result is true if the script evaluated
// to the boolean result true, false otherwise.
IPC_MESSAGE_ROUTED2(ViewHostMsg_ScriptEvalResponse,
int /* id */,
- bool /* result */)
+ ListValue /* result */)
// Updates the content restrictions, i.e. to disable print/copy.
IPC_MESSAGE_ROUTED1(ViewHostMsg_UpdateContentRestrictions,
@@ -3028,11 +3029,12 @@ IPC_BEGIN_MESSAGES(ViewHost)
SkBitmap /* thumbnail */)
// Response from ViewMsg_ScriptEvalRequest. The ID is the parameter supplied
- // to ViewMsg_ScriptEvalRequest. The result is true if the script evaluated
- // to the boolean result true, false otherwise.
+ // to ViewMsg_ScriptEvalRequest. The result has the value returned by the
+ // script as it's only element, one of Null, Boolean, Integer, Real, or
+ // String.
IPC_MESSAGE_ROUTED2(ViewHostMsg_ScriptEvalResponse,
int /* id */,

Powered by Google App Engine
This is Rietveld 408576698